@@ -251,28 +251,28 @@
 #define ROOFIT_BUILDS_ITSELF
 // ./core/clingutils/G__dequeDict.cxx
 #include "deque"
-// ./core/clingutils/G__listDict.cxx
-#include "list"
 // ./core/clingutils/G__forward_listDict.cxx
 #include "forward_list"
+// ./core/clingutils/G__listDict.cxx
+#include "list"
 // ./core/clingutils/G__vectorDict.cxx
 #include "vector"
-// ./core/clingutils/G__multisetDict.cxx
-#include "set"
 // ./core/clingutils/G__setDict.cxx
 #include "set"
+// ./core/clingutils/G__multisetDict.cxx
+#include "set"
 // ./core/clingutils/G__multimap2Dict.cxx
 #include "map"
-// ./core/clingutils/G__mapDict.cxx
-#include "map"
 // ./core/clingutils/G__multimapDict.cxx
 #include "map"
+// ./core/clingutils/G__map2Dict.cxx
+#include "map"
+// ./core/clingutils/G__mapDict.cxx
+#include "map"
 // ./core/clingutils/G__unordered_setDict.cxx
 #include "unordered_set"
 // ./core/clingutils/G__unordered_multisetDict.cxx
 #include "unordered_set"
-// ./core/clingutils/G__map2Dict.cxx
-#include "map"
 // ./core/clingutils/G__valarrayDict.cxx
 #include "valarray"
 // ./core/clingutils/G__complexDict.cxx
@@ -1877,6 +1877,8 @@
 #include "RooFit/Detail/CodeSquashContext.h"
 #include "RooFit/Detail/MathFuncs.h"
 #include "RooFit/Detail/NormalizationHelpers.h"
+#include "RooFit/Detail/RooNLLVarNew.h"
+#include "RooFit/Detail/RooNormalizedPdf.h"
 #include "RooFit/EvalContext.h"
 #include "RooFit/Evaluator.h"
 #include "RooFit/Floats.h"
