@@ -68,7 +68,7 @@
 
 #undef R__HAS_TMVACPU /**/
 #define R__HAS_TMVAGPU /**/
-#undef R__HAS_CUDNN /**/
+#define R__HAS_CUDNN /**/
 #define R__HAS_PYMVA /**/
 #undef R__HAS_RMVA /**/
 
